Compute the unbiased variance accounting for empirical autocorrelations
varCor(
x,
effCor = computeEffectiveAutoCorr(x),
na.rm = FALSE,
nEff = computeEffectiveNumObs(x, effAcf = effCor)
)numeric vector
numeric vector of effective correlation components
first entry at zero lag equals one. See computeEffectiveAutoCorr
The effective correlation is passed to computeEffectiveNumObs.
logical. Should missing values be removed?
possibility to specify precomputed number of effective observations for speedup.
numeric scalar of unbiased variation of x
The default uses empirical autocorrelation
estimates from the supplied data up to first negative component.
For short series of x it is strongly recommended to to
provide effCov that was estimated on a longer time series.